<?php

/**
 * Add New User Page
 * Allows administrators to add new users to the system
 */
require_once '../includes/header.php';

// Check if user has admin privileges
if (!hasRole('admin')) {
    setFlashMessage('You do not have permission to access this page.', 'danger');
    redirect('index.php');
}

// Initialize variables
$username = '';
$fullName = '';
$email = '';
$role = '';
$active = true;

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $username = sanitizeInput($conn, $_POST['username']);
    $fullName = sanitizeInput($conn, $_POST['full_name']);
    $email = sanitizeInput($conn, $_POST['email']);
    $password = $_POST['password'];
    $confirmPassword = $_POST['confirm_password'];
    $role = sanitizeInput($conn, $_POST['role']);
    $active = isset($_POST['active']) ? 1 : 0;

    // Validate input
    $errors = [];

    if (empty($username)) {
        $errors[] = 'Username is required.';
    }

    if (empty($fullName)) {
        $errors[] = 'Full name is required.';
    }

    if (empty($email)) {
        $errors[] = 'Email is required.';
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = 'Please enter a valid email address.';
    }

    if (empty($password)) {
        $errors[] = 'Password is required.';
    } elseif (strlen($password) < 8) {
        $errors[] = 'Password must be at least 8 characters long.';
    }

    if ($password !== $confirmPassword) {
        $errors[] = 'Passwords do not match.';
    }

    if (empty($role)) {
        $errors[] = 'Role is required.';
    }

    // Check if username is already taken
    $checkSql = "SELECT COUNT(*) AS count FROM users WHERE username = '$username'";
    $checkResult = executeQuery($conn, $checkSql);
    $check = $checkResult->fetch_assoc();

    if ($check['count'] > 0) {
        $errors[] = 'Username is already taken. Please choose a different username.';
    }

    // Check if email is already in use
    $checkEmailSql = "SELECT COUNT(*) AS count FROM users WHERE email = '$email'";
    $checkEmailResult = executeQuery($conn, $checkEmailSql);
    $checkEmail = $checkEmailResult->fetch_assoc();

    if ($checkEmail['count'] > 0) {
        $errors[] = 'Email is already in use by another user.';
    }

    // If no errors, insert user
    if (empty($errors)) {
        // Hash the password
        $hashedPassword = password_hash($password, PASSWORD_DEFAULT);

        $sql = "INSERT INTO users (
                    username, 
                    password, 
                    full_name, 
                    email, 
                    role, 
                    active
                ) VALUES (
                    '$username', 
                    '$hashedPassword', 
                    '$fullName', 
                    '$email', 
                    '$role', 
                    $active
                )";

        if (executeQuery($conn, $sql)) {
            $userId = $conn->insert_id;

            logActivity('add_user', "Added new user: $username with role: $role");

            setFlashMessage('User added successfully.', 'success');
            redirect('admin/users.php');
        } else {
            $errors[] = 'Error adding user. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Add New User</h1>
    <a href="users.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to Users
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">User Information</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="username" class="form-label">Username *</label>
                    <input type="text" class="form-control" id="username" name="username" value="<?php echo htmlspecialchars($username); ?>" required>
                    <small class="text-muted">Username must be unique and will be used for login</small>
                </div>
                <div class="col-md-6">
                    <label for="full_name" class="form-label">Full Name *</label>
                    <input type="text" class="form-control" id="full_name" name="full_name" value="<?php echo htmlspecialchars($fullName); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="email" class="form-label">Email Address *</label>
                    <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($email); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="role" class="form-label">Role *</label>
                    <select name="role" id="role" class="form-select" required>
                        <option value="">Select Role</option>
                        <option value="admin" <?php echo ($role === 'admin') ? 'selected' : ''; ?>>Administrator</option>
                        <option value="manager" <?php echo ($role === 'manager') ? 'selected' : ''; ?>>Manager</option>
                        <option value="staff" <?php echo ($role === 'staff') ? 'selected' : ''; ?>>Staff</option>
                    </select>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="password" class="form-label">Password *</label>
                    <input type="password" class="form-control" id="password" name="password" required>
                    <small class="text-muted">Password must be at least 8 characters long</small>
                </div>
                <div class="col-md-6">
                    <label for="confirm_password" class="form-label">Confirm Password *</label>
                    <input type="password" class="form-control" id="confirm_password" name="confirm_password" required>
                </div>
            </div>

            <div class="mb-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="active" name="active" value="1" <?php echo $active ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="active">Active</label>
                    <small class="text-muted d-block">Inactive users cannot log in to the system</small>
                </div>
            </div>

            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> User roles define access levels:
                <ul class="mb-0">
                    <li><strong>Administrator:</strong> Full access to all features</li>
                    <li><strong>Manager:</strong> Access to operations and reports, but not user management</li>
                    <li><strong>Staff:</strong> Basic access to daily operations</li>
                </ul>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                <button type="submit" class="btn btn-primary">Add User</button>
            </div>
        </form>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>