/**
 * Darul Kitab ERP System
 * Custom JavaScript Functions
 */

// Initialize when document is ready
document.addEventListener('DOMContentLoaded', function() {
    // Initialize tooltips
    initTooltips();
    
    // Initialize alert dismissal
    initAlertDismissal();
    
    // Initialize form validation
    initFormValidation();
    
    // Initialize dynamic form fields
    initDynamicFormFields();
    
    // Initialize clickable table rows
    initClickableRows();
    
    // Initialize price calculators
    initPriceCalculators();
});

/**
 * Initialize Bootstrap tooltips
 */
function initTooltips() {
    // Check if Bootstrap is available
    if (typeof bootstrap !== 'undefined' && bootstrap.Tooltip) {
        var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
        var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
            return new bootstrap.Tooltip(tooltipTriggerEl);
        });
    }
}

/**
 * Initialize alert dismissal with fade effect
 */
function initAlertDismissal() {
    // Auto-dismiss alerts after 5 seconds
    setTimeout(function() {
        var alerts = document.querySelectorAll('.alert:not(.alert-warning):not(.alert-danger)');
        alerts.forEach(function(alert) {
            if (alert.querySelector('.btn-close')) {
                var closeBtn = alert.querySelector('.btn-close');
                closeBtn.click();
            }
        });
    }, 5000);
}

/**
 * Initialize form validation
 */
function initFormValidation() {
    // Add validation classes to forms with required fields
    var forms = document.querySelectorAll('form');
    forms.forEach(function(form) {
        form.addEventListener('submit', function(event) {
            if (!form.checkValidity()) {
                event.preventDefault();
                event.stopPropagation();
            }
            
            form.classList.add('was-validated');
        }, false);
    });
}

/**
 * Initialize dynamic form fields (for sales orders, etc.)
 */
function initDynamicFormFields() {
    // Handle "Add Item" buttons in forms
    var addItemButtons = document.querySelectorAll('.add-item-row');
    
    addItemButtons.forEach(function(button) {
        button.addEventListener('click', function(e) {
            e.preventDefault();
            
            var container = document.querySelector(button.dataset.container);
            var template = document.querySelector(button.dataset.template);
            
            if (container && template) {
                var clone = template.content.cloneNode(true);
                var rowCount = container.querySelectorAll('.item-row').length;
                
                // Update IDs and names to have proper indexing
                updateElementAttributes(clone, 'id', rowCount);
                updateElementAttributes(clone, 'name', rowCount);
                updateElementAttributes(clone, 'for', rowCount);
                
                // Add remove button functionality
                var removeButton = clone.querySelector('.remove-item');
                if (removeButton) {
                    removeButton.addEventListener('click', function(e) {
                        e.preventDefault();
                        var row = this.closest('.item-row');
                        row.remove();
                        updateTotals(); // Update totals after removing an item
                    });
                }
                
                // Add change event listeners for price calculation
                var quantityInput = clone.querySelector('.item-quantity');
                var priceInput = clone.querySelector('.item-price');
                
                if (quantityInput && priceInput) {
                    quantityInput.addEventListener('input', updateRowTotal);
                    priceInput.addEventListener('input', updateRowTotal);
                }
                
                container.appendChild(clone);
            }
        });
    });
}

/**
 * Update attributes in cloned templates
 */
function updateElementAttributes(element, attribute, index) {
    var elements = element.querySelectorAll('[' + attribute + ']');
    
    elements.forEach(function(el) {
        var attr = el.getAttribute(attribute);
        el.setAttribute(attribute, attr.replace(/_\d+_|_index_/g, '_' + index + '_'));
    });
}

/**
 * Initialize clickable table rows
 */
function initClickableRows() {
    var clickableRows = document.querySelectorAll('tr.clickable-row');
    
    clickableRows.forEach(function(row) {
        row.addEventListener('click', function() {
            window.location = row.dataset.href;
        });
    });
}

/**
 * Initialize price calculators
 */
function initPriceCalculators() {
    // For sales orders, add event listeners to quantity and price inputs
    var quantityInputs = document.querySelectorAll('.item-quantity');
    var priceInputs = document.querySelectorAll('.item-price');
    
    quantityInputs.forEach(function(input) {
        input.addEventListener('input', updateRowTotal);
    });
    
    priceInputs.forEach(function(input) {
        input.addEventListener('input', updateRowTotal);
    });
    
    // Initial calculation
    updateTotals();
}

/**
 * Update the total for a single row
 */
function updateRowTotal() {
    var row = this.closest('.item-row');
    
    if (row) {
        var quantity = parseFloat(row.querySelector('.item-quantity').value) || 0;
        var price = parseFloat(row.querySelector('.item-price').value) || 0;
        var totalElement = row.querySelector('.item-total');
        
        if (totalElement) {
            var total = quantity * price;
            totalElement.textContent = total.toFixed(2);
            row.dataset.total = total;
            
            // Update the grand total
            updateTotals();
        }
    }
}

/**
 * Update the grand total
 */
function updateTotals() {
    var grandTotal = 0;
    var rows = document.querySelectorAll('.item-row');
    
    rows.forEach(function(row) {
        grandTotal += parseFloat(row.dataset.total || 0);
    });
    
    var grandTotalElement = document.getElementById('grand-total');
    if (grandTotalElement) {
        grandTotalElement.textContent = grandTotal.toFixed(2);
    }
    
    // Update hidden total input if it exists
    var totalInput = document.getElementById('total_amount');
    if (totalInput) {
        totalInput.value = grandTotal.toFixed(2);
    }
}

/**
 * Handle customer type selection to apply appropriate pricing
 */
function handleCustomerTypeChange(select) {
    var customerType = select.value;
    var bookSelects = document.querySelectorAll('.book-select');
    
    bookSelects.forEach(function(bookSelect) {
        var row = bookSelect.closest('.item-row');
        var priceInput = row.querySelector('.item-price');
        var selectedOption = bookSelect.options[bookSelect.selectedIndex];
        
        if (selectedOption) {
            var wholesalePrice = selectedOption.dataset.wholesalePrice;
            var retailPrice = selectedOption.dataset.retailPrice;
            
            if (priceInput) {
                priceInput.value = (customerType === 'wholesale') ? wholesalePrice : retailPrice;
                // Trigger price update
                var event = new Event('input', { bubbles: true });
                priceInput.dispatchEvent(event);
            }
        }
    });
}

/**
 * Handle book selection to update price based on customer type
 */
function handleBookSelection(select) {
    var selectedOption = select.options[select.selectedIndex];
    var row = select.closest('.item-row');
    var priceInput = row.querySelector('.item-price');
    
    if (selectedOption && priceInput) {
        var customerTypeSelect = document.getElementById('customer_type');
        var customerType = customerTypeSelect ? customerTypeSelect.value : 'retail';
        
        var wholesalePrice = selectedOption.dataset.wholesalePrice;
        var retailPrice = selectedOption.dataset.retailPrice;
        
        priceInput.value = (customerType === 'wholesale') ? wholesalePrice : retailPrice;
        
        // Trigger price update
        var event = new Event('input', { bubbles: true });
        priceInput.dispatchEvent(event);
    }
}

/**
 * Format number as currency
 */
function formatCurrency(amount) {
    return '₹ ' + parseFloat(amount).toFixed(2).replace(/\d(?=(\d{3})+\.)/g, '$&,');
}

/**
 * Print the current page or a specific element
 */
function printContent(elementId) {
    var element = document.getElementById(elementId);
    var originalContents = document.body.innerHTML;
    
    if (element) {
        document.body.innerHTML = element.innerHTML;
        window.print();
        document.body.innerHTML = originalContents;
    } else {
        window.print();
    }
}

/**
 * Confirm deletion with custom message
 */
function confirmDelete(message, defaultMessage) {
    var confirmMessage = message || defaultMessage || 'Are you sure you want to delete this item?';
    return confirm(confirmMessage);
}