<?php

/**
 * Add New Book Page
 * Allows adding new books to the catalog
 */
require_once '../includes/header.php';

// Initialize variables
$title = '';
$author = '';
$isbn = '';
$pagesPerBook = '';
$wholesalePrice = '';
$retailPrice = '';
$active = true;

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $title = sanitizeInput($conn, $_POST['title']);
    $author = sanitizeInput($conn, $_POST['author']);
    $isbn = sanitizeInput($conn, $_POST['isbn']);
    $pagesPerBook = (int)$_POST['pages_per_book'];
    $wholesalePrice = (float)$_POST['wholesale_price'];
    $retailPrice = (float)$_POST['retail_price'];
    $active = isset($_POST['active']) ? 1 : 0;

    // Validate input
    $errors = [];

    if (empty($title)) {
        $errors[] = 'Book title is required.';
    }

    if (empty($author)) {
        $errors[] = 'Author name is required.';
    }

    if ($pagesPerBook <= 0) {
        $errors[] = 'Pages per book must be greater than zero.';
    }

    if ($wholesalePrice <= 0) {
        $errors[] = 'Wholesale price must be greater than zero.';
    }

    if ($retailPrice <= 0) {
        $errors[] = 'Retail price must be greater than zero.';
    }

    if ($retailPrice <= $wholesalePrice) {
        $errors[] = 'Retail price should be greater than wholesale price.';
    }

    // Check if ISBN is unique (if provided)
    if (!empty($isbn)) {
        $checkSql = "SELECT COUNT(*) AS count FROM books WHERE isbn = '$isbn'";
        $checkResult = executeQuery($conn, $checkSql);
        $row = $checkResult->fetch_assoc();

        if ($row['count'] > 0) {
            $errors[] = 'ISBN already exists in the system. Please use a unique ISBN.';
        }
    }

    // If no errors, insert data
    if (empty($errors)) {
        $sql = "INSERT INTO books (
                    title, 
                    author, 
                    isbn, 
                    pages_per_book, 
                    wholesale_price, 
                    retail_price, 
                    active
                ) VALUES (
                    '$title', 
                    '$author', 
                    " . (!empty($isbn) ? "'$isbn'" : "NULL") . ", 
                    $pagesPerBook, 
                    $wholesalePrice, 
                    $retailPrice, 
                    $active
                )";

        if (executeQuery($conn, $sql)) {
            $bookId = $conn->insert_id;

            logActivity('add_book', "Added new book: $title");

            setFlashMessage('Book added successfully.', 'success');
            redirect('books/list.php');
        } else {
            $errors[] = 'Error adding book. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Add New Book</h1>
    <a href="list.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to List
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Book Details</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="title" class="form-label">Book Title *</label>
                    <input type="text" class="form-control" id="title" name="title" value="<?php echo htmlspecialchars($title); ?>" required>
                </div>
                <div class="col-md-6">
                    <label for="author" class="form-label">Author *</label>
                    <input type="text" class="form-control" id="author" name="author" value="<?php echo htmlspecialchars($author); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="isbn" class="form-label">ISBN</label>
                    <input type="text" class="form-control" id="isbn" name="isbn" value="<?php echo htmlspecialchars($isbn); ?>">
                    <small class="text-muted">Optional. Must be unique if provided.</small>
                </div>
                <div class="col-md-6">
                    <label for="pages_per_book" class="form-label">Pages Per Book *</label>
                    <input type="number" class="form-control" id="pages_per_book" name="pages_per_book" value="<?php echo htmlspecialchars($pagesPerBook); ?>" min="1" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="wholesale_price" class="form-label">Wholesale Price *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="wholesale_price" name="wholesale_price" value="<?php echo htmlspecialchars($wholesalePrice); ?>" min="0.01" step="0.01" required>
                    </div>
                    <small class="text-muted">Price for wholesale customers</small>
                </div>
                <div class="col-md-6">
                    <label for="retail_price" class="form-label">Retail Price *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="retail_price" name="retail_price" value="<?php echo htmlspecialchars($retailPrice); ?>" min="0.01" step="0.01" required>
                    </div>
                    <small class="text-muted">Price for retail customers</small>
                </div>
            </div>

            <div class="mb-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" id="active" name="active" value="1" <?php echo $active ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="active">Active</label>
                    <small class="text-muted d-block">Inactive books won't appear in sales and production forms</small>
                </div>
            </div>

            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> Note: After adding a book, you can create production orders from the Production menu.
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                <button type="submit" class="btn btn-primary">Add Book</button>
            </div>
        </form>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>