<?php

/**
 * Financial Reports Page
 * Displays various financial reports and analytics
 */
require_once '../includes/header.php';

// Get filter parameters
$reportType = isset($_GET['report']) ? sanitizeInput($conn, $_GET['report']) : 'profit_loss';
$startDate = isset($_GET['start_date']) ? sanitizeInput($conn, $_GET['start_date']) : date('Y-m-01'); // First day of current month
$endDate = isset($_GET['end_date']) ? sanitizeInput($conn, $_GET['end_date']) : date('Y-m-t'); // Last day of current month

// Profit & Loss Report
function getProfitLossData($conn, $startDate, $endDate)
{
    // Revenue data
    $revenueSql = "SELECT 
                    SUM(paid_amount) AS total_revenue
                   FROM sales_orders
                   WHERE order_date BETWEEN '$startDate' AND '$endDate'";
    $revenueResult = executeQuery($conn, $revenueSql);
    $revenue = $revenueResult->fetch_assoc();

    // Expense data by type
    $expensesSql = "SELECT 
                     expense_type,
                     SUM(amount) AS total_amount
                    FROM expenses
                    WHERE payment_date BETWEEN '$startDate' AND '$endDate'
                    GROUP BY expense_type";
    $expensesResult = executeQuery($conn, $expensesSql);

    $expenses = [
        'debt' => 0,
        'salary' => 0,
        'miscellaneous' => 0
    ];

    if ($expensesResult && $expensesResult->num_rows > 0) {
        while ($expense = $expensesResult->fetch_assoc()) {
            $expenses[$expense['expense_type']] = $expense['total_amount'];
        }
    }

    // Production costs for books sold in this period
    $productionCostsSql = "SELECT 
                             SUM(fi.production_cost_per_unit * soi.quantity) AS total_production_cost
                           FROM sales_order_items soi
                           JOIN sales_orders so ON soi.sales_order_id = so.id
                           JOIN finished_inventory fi ON soi.book_id = fi.book_id
                           WHERE so.order_date BETWEEN '$startDate' AND '$endDate'";
    $productionCostsResult = executeQuery($conn, $productionCostsSql);
    $productionCosts = $productionCostsResult->fetch_assoc();

    // Owner withdrawals
    $withdrawalsSql = "SELECT 
                        SUM(amount) AS total_withdrawals
                       FROM owner_withdrawals
                       WHERE withdrawal_date BETWEEN '$startDate' AND '$endDate'";
    $withdrawalsResult = executeQuery($conn, $withdrawalsSql);
    $withdrawals = $withdrawalsResult->fetch_assoc();

    // Calculate totals
    $totalExpenses = $expenses['debt'] + $expenses['salary'] + $expenses['miscellaneous'] + ($productionCosts['total_production_cost'] ?? 0);
    $netProfit = ($revenue['total_revenue'] ?? 0) - $totalExpenses;
    $retainedEarnings = $netProfit - ($withdrawals['total_withdrawals'] ?? 0);

    return [
        'revenue' => $revenue['total_revenue'] ?? 0,
        'expenses' => $expenses,
        'production_costs' => $productionCosts['total_production_cost'] ?? 0,
        'total_expenses' => $totalExpenses,
        'net_profit' => $netProfit,
        'withdrawals' => $withdrawals['total_withdrawals'] ?? 0,
        'retained_earnings' => $retainedEarnings
    ];
}

// Balance Sheet Report
function getBalanceSheetData($conn)
{
    // Assets

    // Cash (calculated as revenue - expenses - withdrawals)
    $cashSql = "SELECT 
                (SELECT SUM(paid_amount) FROM sales_orders) -
                (SELECT SUM(amount) FROM expenses) -
                (SELECT SUM(amount) FROM owner_withdrawals) AS cash_balance";
    $cashResult = executeQuery($conn, $cashSql);
    $cash = $cashResult->fetch_assoc()['cash_balance'] ?? 0;

    // Accounts Receivable (unpaid sales)
    $receivablesSql = "SELECT SUM(total_amount - paid_amount) AS accounts_receivable
                      FROM sales_orders
                      WHERE payment_status != 'paid'";
    $receivablesResult = executeQuery($conn, $receivablesSql);
    $receivables = $receivablesResult->fetch_assoc()['accounts_receivable'] ?? 0;

    // Inventory Value (raw materials)
    $rawMaterialsSql = "SELECT 
                        material_type,
                        SUM(remaining_quantity * unit_price) AS total_value
                       FROM raw_materials
                       GROUP BY material_type";
    $rawMaterialsResult = executeQuery($conn, $rawMaterialsSql);

    $rawMaterials = [
        'paper' => 0,
        'cover' => 0,
        'half_title' => 0
    ];

    if ($rawMaterialsResult && $rawMaterialsResult->num_rows > 0) {
        while ($material = $rawMaterialsResult->fetch_assoc()) {
            $rawMaterials[$material['material_type']] = $material['total_value'];
        }
    }

    // Finished Goods Inventory
    $finishedGoodsSql = "SELECT SUM(quantity * production_cost_per_unit) AS total_value
                         FROM finished_inventory";
    $finishedGoodsResult = executeQuery($conn, $finishedGoodsSql);
    $finishedGoods = $finishedGoodsResult->fetch_assoc()['total_value'] ?? 0;

    // Liabilities

    // Accounts Payable (unpaid printing/binding jobs)
    $printingPayablesSql = "SELECT SUM(total_cost - payment_amount) AS printing_payables
                           FROM printing_jobs
                           WHERE payment_status != 'paid'";
    $printingPayablesResult = executeQuery($conn, $printingPayablesSql);
    $printingPayables = $printingPayablesResult->fetch_assoc()['printing_payables'] ?? 0;

    $bindingPayablesSql = "SELECT SUM(total_cost - payment_amount) AS binding_payables
                           FROM binding_jobs
                           WHERE payment_status != 'paid'";
    $bindingPayablesResult = executeQuery($conn, $bindingPayablesSql);
    $bindingPayables = $bindingPayablesResult->fetch_assoc()['binding_payables'] ?? 0;

    // Total Calculations
    $totalRawMaterials = $rawMaterials['paper'] + $rawMaterials['cover'] + $rawMaterials['half_title'];
    $totalInventory = $totalRawMaterials + $finishedGoods;
    $totalAssets = $cash + $receivables + $totalInventory;

    $totalLiabilities = $printingPayables + $bindingPayables;
    $equity = $totalAssets - $totalLiabilities;

    return [
        'assets' => [
            'cash' => $cash,
            'accounts_receivable' => $receivables,
            'raw_materials' => $rawMaterials,
            'total_raw_materials' => $totalRawMaterials,
            'finished_goods' => $finishedGoods,
            'total_inventory' => $totalInventory,
            'total_assets' => $totalAssets
        ],
        'liabilities' => [
            'printing_payables' => $printingPayables,
            'binding_payables' => $bindingPayables,
            'total_liabilities' => $totalLiabilities
        ],
        'equity' => $equity
    ];
}

// Sales Report
function getSalesReportData($conn, $startDate, $endDate)
{
    // Sales by book
    $salesByBookSql = "SELECT 
                        b.id,
                        b.title,
                        b.author,
                        SUM(soi.quantity) AS total_quantity,
                        SUM(soi.total_price) AS total_sales,
                        AVG(soi.unit_price) AS avg_price
                       FROM sales_order_items soi
                       JOIN books b ON soi.book_id = b.id
                       JOIN sales_orders so ON soi.sales_order_id = so.id
                       WHERE so.order_date BETWEEN '$startDate' AND '$endDate'
                       GROUP BY b.id
                       ORDER BY total_sales DESC";
    $salesByBookResult = executeQuery($conn, $salesByBookSql);

    $salesByBook = [];
    if ($salesByBookResult && $salesByBookResult->num_rows > 0) {
        while ($row = $salesByBookResult->fetch_assoc()) {
            $salesByBook[] = $row;
        }
    }

    // Sales by customer type
    $salesByTypeSql = "SELECT 
                        c.customer_type,
                        COUNT(DISTINCT so.id) AS order_count,
                        SUM(so.paid_amount) AS total_sales
                       FROM sales_orders so
                       JOIN customers c ON so.customer_id = c.id
                       WHERE so.order_date BETWEEN '$startDate' AND '$endDate'
                       GROUP BY c.customer_type";
    $salesByTypeResult = executeQuery($conn, $salesByTypeSql);

    $salesByType = [
        'wholesale' => ['order_count' => 0, 'total_sales' => 0],
        'retail' => ['order_count' => 0, 'total_sales' => 0]
    ];

    if ($salesByTypeResult && $salesByTypeResult->num_rows > 0) {
        while ($row = $salesByTypeResult->fetch_assoc()) {
            $salesByType[$row['customer_type']] = [
                'order_count' => $row['order_count'],
                'total_sales' => $row['total_sales']
            ];
        }
    }

    // Monthly sales trend
    $monthlySalesSql = "SELECT 
                         DATE_FORMAT(order_date, '%Y-%m') AS month,
                         SUM(paid_amount) AS monthly_sales
                        FROM sales_orders
                        WHERE order_date BETWEEN DATE_FORMAT('$startDate', '%Y-%m-01') AND LAST_DAY('$endDate')
                        GROUP BY DATE_FORMAT(order_date, '%Y-%m')
                        ORDER BY month";
    $monthlySalesResult = executeQuery($conn, $monthlySalesSql);

    $monthlySales = [];
    if ($monthlySalesResult && $monthlySalesResult->num_rows > 0) {
        while ($row = $monthlySalesResult->fetch_assoc()) {
            $monthlySales[] = $row;
        }
    }

    $totalSales = $salesByType['wholesale']['total_sales'] + $salesByType['retail']['total_sales'];
    $totalOrders = $salesByType['wholesale']['order_count'] + $salesByType['retail']['order_count'];

    return [
        'sales_by_book' => $salesByBook,
        'sales_by_type' => $salesByType,
        'monthly_sales' => $monthlySales,
        'total_sales' => $totalSales,
        'total_orders' => $totalOrders
    ];
}

// Get the appropriate report data based on the selected type
$reportData = null;
switch ($reportType) {
    case 'profit_loss':
        $reportData = getProfitLossData($conn, $startDate, $endDate);
        break;
    case 'balance_sheet':
        $reportData = getBalanceSheetData($conn);
        break;
    case 'sales_report':
        $reportData = getSalesReportData($conn, $startDate, $endDate);
        break;
    default:
        $reportData = getProfitLossData($conn, $startDate, $endDate);
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Financial Reports</h1>
    <div>
        <a href="expenses.php" class="btn btn-info me-2">
            <i class="fas fa-money-bill-wave"></i> Expenses
        </a>
        <a href="withdrawals.php" class="btn btn-primary">
            <i class="fas fa-hand-holding-usd"></i> Withdrawals
        </a>
    </div>
</div>

<!-- Report Selection -->
<div class="card mb-4">
    <div class="card-header">
        <i class="fas fa-file-alt"></i> Select Report
    </div>
    <div class="card-body">
        <form method="get" action="" class="row g-3">
            <div class="col-md-3">
                <label for="report" class="form-label">Report Type</label>
                <select name="report" id="report" class="form-select" onchange="toggleDateFields()">
                    <option value="profit_loss" <?php echo ($reportType === 'profit_loss') ? 'selected' : ''; ?>>Profit & Loss Statement</option>
                    <option value="balance_sheet" <?php echo ($reportType === 'balance_sheet') ? 'selected' : ''; ?>>Balance Sheet</option>
                    <option value="sales_report" <?php echo ($reportType === 'sales_report') ? 'selected' : ''; ?>>Sales Report</option>
                </select>
            </div>
            <div class="col-md-3 date-field">
                <label for="start_date" class="form-label">Start Date</label>
                <input type="date" class="form-control" id="start_date" name="start_date" value="<?php echo htmlspecialchars($startDate); ?>">
            </div>
            <div class="col-md-3 date-field">
                <label for="end_date" class="form-label">End Date</label>
                <input type="date" class="form-control" id="end_date" name="end_date" value="<?php echo htmlspecialchars($endDate); ?>">
            </div>
            <div class="col-md-3 d-flex align-items-end">
                <button type="submit" class="btn btn-primary w-100">Generate Report</button>
            </div>
        </form>
    </div>
</div>

<?php if ($reportType === 'profit_loss'): ?>
    <!-- Profit & Loss Statement -->
    <div class="card shadow mb-4">
        <div class="card-header py-3 d-flex justify-content-between align-items-center">
            <h6 class="m-0 font-weight-bold text-primary">Profit & Loss Statement</h6>
            <h6 class="m-0"><?php echo formatDate($startDate); ?> to <?php echo formatDate($endDate); ?></h6>
        </div>
        <div class="card-body">
            <div class="row">
                <div class="col-md-8">
                    <table class="table table-bordered">
                        <tr class="table-secondary">
                            <th colspan="2">Revenue</th>
                        </tr>
                        <tr>
                            <td>Sales Revenue</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['revenue']); ?></td>
                        </tr>
                        <tr class="table-secondary">
                            <th colspan="2">Expenses</th>
                        </tr>
                        <tr>
                            <td>Production Costs</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['production_costs']); ?></td>
                        </tr>
                        <tr>
                            <td>Debt Payments</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['expenses']['debt']); ?></td>
                        </tr>
                        <tr>
                            <td>Salary Payments</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['expenses']['salary']); ?></td>
                        </tr>
                        <tr>
                            <td>Miscellaneous Expenses</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['expenses']['miscellaneous']); ?></td>
                        </tr>
                        <tr class="table-danger">
                            <th>Total Expenses</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['total_expenses']); ?></th>
                        </tr>
                        <tr class="table-success">
                            <th>Net Profit</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['net_profit']); ?></th>
                        </tr>
                        <tr class="table-secondary">
                            <th colspan="2">Distributions</th>
                        </tr>
                        <tr>
                            <td>Owner Withdrawals</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['withdrawals']); ?></td>
                        </tr>
                        <tr class="table-primary">
                            <th>Retained Earnings</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['retained_earnings']); ?></th>
                        </tr>
                    </table>
                </div>
                <div class="col-md-4">
                    <div class="card h-100">
                        <div class="card-header">
                            <h6 class="m-0 font-weight-bold">Expense Breakdown</h6>
                        </div>
                        <div class="card-body">
                            <div class="chart-container" style="position: relative; height:300px; width:100%">
                                <canvas id="expenseBreakdownChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Financial Performance -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Financial Performance</h6>
        </div>
        <div class="card-body">
            <div class="chart-container" style="position: relative; height:400px; width:100%">
                <canvas id="financialPerformanceChart"></canvas>
            </div>
        </div>
    </div>

<?php elseif ($reportType === 'balance_sheet'): ?>
    <!-- Balance Sheet -->
    <div class="card shadow mb-4">
        <div class="card-header py-3 d-flex justify-content-between align-items-center">
            <h6 class="m-0 font-weight-bold text-primary">Balance Sheet</h6>
            <h6 class="m-0">As of <?php echo formatDate(date('Y-m-d')); ?></h6>
        </div>
        <div class="card-body">
            <div class="row">
                <div class="col-md-6">
                    <h5 class="text-primary mb-3">Assets</h5>
                    <table class="table table-bordered">
                        <tr class="table-secondary">
                            <th colspan="2">Current Assets</th>
                        </tr>
                        <tr>
                            <td>Cash</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['assets']['cash']); ?></td>
                        </tr>
                        <tr>
                            <td>Accounts Receivable</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['assets']['accounts_receivable']); ?></td>
                        </tr>
                        <tr class="table-secondary">
                            <th colspan="2">Inventory</th>
                        </tr>
                        <tr>
                            <td>Raw Materials - Paper</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['assets']['raw_materials']['paper']); ?></td>
                        </tr>
                        <tr>
                            <td>Raw Materials - Cover</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['assets']['raw_materials']['cover']); ?></td>
                        </tr>
                        <tr>
                            <td>Raw Materials - Half Title</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['assets']['raw_materials']['half_title']); ?></td>
                        </tr>
                        <tr>
                            <td>Finished Goods</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['assets']['finished_goods']); ?></td>
                        </tr>
                        <tr class="table-info">
                            <th>Total Inventory</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['assets']['total_inventory']); ?></th>
                        </tr>
                        <tr class="table-success">
                            <th>Total Assets</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['assets']['total_assets']); ?></th>
                        </tr>
                    </table>
                </div>
                <div class="col-md-6">
                    <h5 class="text-primary mb-3">Liabilities & Equity</h5>
                    <table class="table table-bordered">
                        <tr class="table-secondary">
                            <th colspan="2">Current Liabilities</th>
                        </tr>
                        <tr>
                            <td>Printing Payables</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['liabilities']['printing_payables']); ?></td>
                        </tr>
                        <tr>
                            <td>Binding Payables</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['liabilities']['binding_payables']); ?></td>
                        </tr>
                        <tr class="table-danger">
                            <th>Total Liabilities</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['liabilities']['total_liabilities']); ?></th>
                        </tr>
                        <tr class="table-secondary">
                            <th colspan="2">Equity</th>
                        </tr>
                        <tr>
                            <td>Owner's Equity</td>
                            <td class="text-end"><?php echo formatCurrency($reportData['equity']); ?></td>
                        </tr>
                        <tr class="table-primary">
                            <th>Total Liabilities & Equity</th>
                            <th class="text-end"><?php echo formatCurrency($reportData['liabilities']['total_liabilities'] + $reportData['equity']); ?></th>
                        </tr>
                    </table>

                    <div class="card mt-4">
                        <div class="card-header">
                            <h6 class="m-0 font-weight-bold">Asset Distribution</h6>
                        </div>
                        <div class="card-body">
                            <div class="chart-container" style="position: relative; height:250px; width:100%">
                                <canvas id="assetDistributionChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

<?php elseif ($reportType === 'sales_report'): ?>
    <!-- Sales Report -->
    <div class="card shadow mb-4">
        <div class="card-header py-3 d-flex justify-content-between align-items-center">
            <h6 class="m-0 font-weight-bold text-primary">Sales Report</h6>
            <h6 class="m-0"><?php echo formatDate($startDate); ?> to <?php echo formatDate($endDate); ?></h6>
        </div>
        <div class="card-body">
            <div class="row mb-4">
                <!-- Total Sales -->
                <div class="col-xl-3 col-md-6 mb-4">
                    <div class="card border-left-primary shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">
                                        Total Sales</div>
                                    <div class="h5 mb-0 font-weight-bold text-gray-800">
                                        <?php echo formatCurrency($reportData['total_sales']); ?>
                                    </div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-dollar-sign fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Total Orders -->
                <div class="col-xl-3 col-md-6 mb-4">
                    <div class="card border-left-success shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-success text-uppercase mb-1">
                                        Total Orders</div>
                                    <div class="h5 mb-0 font-weight-bold text-gray-800">
                                        <?php echo number_format($reportData['total_orders']); ?>
                                    </div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-shopping-cart fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Wholesale Sales -->
                <div class="col-xl-3 col-md-6 mb-4">
                    <div class="card border-left-info shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-info text-uppercase mb-1">
                                        Wholesale Sales</div>
                                    <div class="h5 mb-0 font-weight-bold text-gray-800">
                                        <?php echo formatCurrency($reportData['sales_by_type']['wholesale']['total_sales']); ?>
                                    </div>
                                    <div class="small mt-2">
                                        <?php echo number_format($reportData['sales_by_type']['wholesale']['order_count']); ?> orders
                                    </div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-warehouse fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Retail Sales -->
                <div class="col-xl-3 col-md-6 mb-4">
                    <div class="card border-left-warning shadow h-100 py-2">
                        <div class="card-body">
                            <div class="row no-gutters align-items-center">
                                <div class="col mr-2">
                                    <div class="text-xs font-weight-bold text-warning text-uppercase mb-1">
                                        Retail Sales</div>
                                    <div class="h5 mb-0 font-weight-bold text-gray-800">
                                        <?php echo formatCurrency($reportData['sales_by_type']['retail']['total_sales']); ?>
                                    </div>
                                    <div class="small mt-2">
                                        <?php echo number_format($reportData['sales_by_type']['retail']['order_count']); ?> orders
                                    </div>
                                </div>
                                <div class="col-auto">
                                    <i class="fas fa-user fa-2x text-gray-300"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Sales by Book -->
            <div class="table-responsive mb-4">
                <h5 class="mb-3">Sales by Book</h5>
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>Book Title</th>
                            <th>Author</th>
                            <th>Quantity Sold</th>
                            <th>Average Price</th>
                            <th>Total Sales</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($reportData['sales_by_book'])): ?>
                            <?php foreach ($reportData['sales_by_book'] as $book): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($book['title']); ?></td>
                                    <td><?php echo htmlspecialchars($book['author']); ?></td>
                                    <td><?php echo number_format($book['total_quantity']); ?></td>
                                    <td><?php echo formatCurrency($book['avg_price']); ?></td>
                                    <td><?php echo formatCurrency($book['total_sales']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="5" class="text-center">No sales data found for this period</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- Sales Trends Chart -->
            <div class="chart-container" style="position: relative; height:400px; width:100%">
                <h5 class="mb-3">Monthly Sales Trend</h5>
                <canvas id="monthlySalesChart"></canvas>
            </div>

            <!-- Sales Distribution Chart -->
            <div class="row mt-4">
                <div class="col-md-6">
                    <div class="card">
                        <div class="card-header">
                            <h6 class="m-0 font-weight-bold">Sales Distribution by Customer Type</h6>
                        </div>
                        <div class="card-body">
                            <div class="chart-container" style="position: relative; height:250px; width:100%">
                                <canvas id="salesDistributionChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-6">
                    <div class="card">
                        <div class="card-header">
                            <h6 class="m-0 font-weight-bold">Top Selling Books</h6>
                        </div>
                        <div class="card-body">
                            <div class="chart-container" style="position: relative; height:250px; width:100%">
                                <canvas id="topBooksChart"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php endif; ?>

<!-- Scripts for Charts -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Toggle date fields based on report type
    function toggleDateFields() {
        const reportType = document.getElementById('report').value;
        const dateFields = document.querySelectorAll('.date-field');

        if (reportType === 'balance_sheet') {
            dateFields.forEach(field => {
                field.style.display = 'none';
            });
        } else {
            dateFields.forEach(field => {
                field.style.display = 'block';
            });
        }
    }

    // Initialize date fields visibility
    toggleDateFields();

    <?php if ($reportType === 'profit_loss'): ?>
        // Expense Breakdown Chart
        const expenseCtx = document.getElementById('expenseBreakdownChart').getContext('2d');
        const expenseBreakdownChart = new Chart(expenseCtx, {
            type: 'pie',
            data: {
                labels: ['Production Costs', 'Debt Payments', 'Salary Payments', 'Miscellaneous'],
                datasets: [{
                    data: [
                        <?php echo $reportData['production_costs']; ?>,
                        <?php echo $reportData['expenses']['debt']; ?>,
                        <?php echo $reportData['expenses']['salary']; ?>,
                        <?php echo $reportData['expenses']['miscellaneous']; ?>
                    ],
                    backgroundColor: [
                        'rgba(54, 162, 235, 0.8)',
                        'rgba(255, 99, 132, 0.8)',
                        'rgba(75, 192, 192, 0.8)',
                        'rgba(255, 206, 86, 0.8)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false
            }
        });

        // Financial Performance Chart
        const perfCtx = document.getElementById('financialPerformanceChart').getContext('2d');
        const financialPerformanceChart = new Chart(perfCtx, {
            type: 'bar',
            data: {
                labels: ['Revenue', 'Expenses', 'Net Profit', 'Withdrawals', 'Retained Earnings'],
                datasets: [{
                    label: 'Amount (₹)',
                    data: [
                        <?php echo $reportData['revenue']; ?>,
                        <?php echo $reportData['total_expenses']; ?>,
                        <?php echo $reportData['net_profit']; ?>,
                        <?php echo $reportData['withdrawals']; ?>,
                        <?php echo $reportData['retained_earnings']; ?>
                    ],
                    backgroundColor: [
                        'rgba(75, 192, 192, 0.8)',
                        'rgba(255, 99, 132, 0.8)',
                        'rgba(54, 162, 235, 0.8)',
                        'rgba(255, 159, 64, 0.8)',
                        'rgba(153, 102, 255, 0.8)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        ticks: {
                            callback: function(value) {
                                return '₹' + value.toLocaleString('en-IN');
                            }
                        }
                    }
                },
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                let label = context.dataset.label || '';
                                let value = context.raw || 0;
                                return label + ': ₹' + value.toLocaleString('en-IN', {
                                    minimumFractionDigits: 2,
                                    maximumFractionDigits: 2
                                });
                            }
                        }
                    }
                }
            }
        });
    <?php endif; ?>

    <?php if ($reportType === 'balance_sheet'): ?>
        // Asset Distribution Chart
        const assetCtx = document.getElementById('assetDistributionChart').getContext('2d');
        const assetDistributionChart = new Chart(assetCtx, {
            type: 'doughnut',
            data: {
                labels: ['Cash', 'Accounts Receivable', 'Raw Materials', 'Finished Goods'],
                datasets: [{
                    data: [
                        <?php echo $reportData['assets']['cash']; ?>,
                        <?php echo $reportData['assets']['accounts_receivable']; ?>,
                        <?php echo $reportData['assets']['total_raw_materials']; ?>,
                        <?php echo $reportData['assets']['finished_goods']; ?>
                    ],
                    backgroundColor: [
                        'rgba(75, 192, 192, 0.8)',
                        'rgba(54, 162, 235, 0.8)',
                        'rgba(255, 206, 86, 0.8)',
                        'rgba(153, 102, 255, 0.8)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                let label = context.label || '';
                                let value = context.raw || 0;
                                let total = context.dataset.data.reduce((acc, val) => acc + val, 0);
                                let percentage = ((value / total) * 100).toFixed(1);
                                return label + ': ₹' + value.toLocaleString('en-IN', {
                                    minimumFractionDigits: 2,
                                    maximumFractionDigits: 2
                                }) + ' (' + percentage + '%)';
                            }
                        }
                    }
                }
            }
        });
    <?php endif; ?>

    <?php if ($reportType === 'sales_report'): ?>
        // Monthly Sales Chart
        const salesCtx = document.getElementById('monthlySalesChart').getContext('2d');
        const monthlySalesChart = new Chart(salesCtx, {
            type: 'line',
            data: {
                labels: [
                    <?php
                    $labels = [];
                    foreach ($reportData['monthly_sales'] as $month) {
                        $monthLabel = date('M Y', strtotime($month['month'] . '-01'));
                        $labels[] = "'$monthLabel'";
                    }
                    echo implode(', ', $labels);
                    ?>
                ],
                datasets: [{
                    label: 'Monthly Sales',
                    data: [
                        <?php
                        $values = [];
                        foreach ($reportData['monthly_sales'] as $month) {
                            $values[] = $month['monthly_sales'];
                        }
                        echo implode(', ', $values);
                        ?>
                    ],
                    fill: false,
                    borderColor: 'rgba(75, 192, 192, 1)',
                    tension: 0.1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        ticks: {
                            callback: function(value) {
                                return '₹' + value.toLocaleString('en-IN');
                            }
                        }
                    }
                },
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                let label = context.dataset.label || '';
                                let value = context.raw || 0;
                                return label + ': ₹' + value.toLocaleString('en-IN', {
                                    minimumFractionDigits: 2,
                                    maximumFractionDigits: 2
                                });
                            }
                        }
                    }
                }
            }
        });

        // Sales Distribution Chart
        const distCtx = document.getElementById('salesDistributionChart').getContext('2d');
        const salesDistributionChart = new Chart(distCtx, {
            type: 'pie',
            data: {
                labels: ['Wholesale', 'Retail'],
                datasets: [{
                    data: [
                        <?php echo $reportData['sales_by_type']['wholesale']['total_sales']; ?>,
                        <?php echo $reportData['sales_by_type']['retail']['total_sales']; ?>
                    ],
                    backgroundColor: [
                        'rgba(54, 162, 235, 0.8)',
                        'rgba(255, 99, 132, 0.8)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                let label = context.label || '';
                                let value = context.raw || 0;
                                let total = context.dataset.data.reduce((acc, val) => acc + val, 0);
                                let percentage = ((value / total) * 100).toFixed(1);
                                return label + ': ₹' + value.toLocaleString('en-IN', {
                                    minimumFractionDigits: 2,
                                    maximumFractionDigits: 2
                                }) + ' (' + percentage + '%)';
                            }
                        }
                    }
                }
            }
        });

        // Top Books Chart
        const booksCtx = document.getElementById('topBooksChart').getContext('2d');
        const topBooksChart = new Chart(booksCtx, {
            type: 'bar',
            data: {
                labels: [
                    <?php
                    $bookLabels = [];
                    $bookCount = 0;
                    foreach ($reportData['sales_by_book'] as $book) {
                        if ($bookCount < 5) {  // Limit to top 5 books
                            $bookLabels[] = "'" . str_replace("'", "\\'", substr($book['title'], 0, 20)) . "'";
                            $bookCount++;
                        }
                    }
                    echo implode(', ', $bookLabels);
                    ?>
                ],
                datasets: [{
                    label: 'Sales Amount',
                    data: [
                        <?php
                        $bookValues = [];
                        $bookCount = 0;
                        foreach ($reportData['sales_by_book'] as $book) {
                            if ($bookCount < 5) {  // Limit to top 5 books
                                $bookValues[] = $book['total_sales'];
                                $bookCount++;
                            }
                        }
                        echo implode(', ', $bookValues);
                        ?>
                    ],
                    backgroundColor: 'rgba(75, 192, 192, 0.8)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        ticks: {
                            callback: function(value) {
                                return '₹' + value.toLocaleString('en-IN');
                            }
                        }
                    }
                },
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                let label = context.dataset.label || '';
                                let value = context.raw || 0;
                                return label + ': ₹' + value.toLocaleString('en-IN', {
                                    minimumFractionDigits: 2,
                                    maximumFractionDigits: 2
                                });
                            }
                        }
                    }
                }
            }
        });
    <?php endif; ?>
</script>

<?php require_once '../includes/footer.php'; ?>