<?php

/**
 * Configuration File
 * Contains global settings, constants, and common functions for the ERP system
 */

// Session settings
session_start();

// Error reporting settings
error_reporting(E_ALL);
ini_set('display_errors', 0); // Set to 1 during development, 0 in production
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/logs/error.log');

// Create logs directory if it doesn't exist
if (!file_exists(__DIR__ . '/logs')) {
    mkdir(__DIR__ . '/logs', 0775, true);
}

// Application settings
define('APP_NAME', 'Darul Kitab ERP');
define('APP_VERSION', '1.0.0');
define('BASE_URL', 'http://' . $_SERVER['HTTP_HOST'] . '/darulkitab/'); // Update with your site URL
define('ADMIN_EMAIL', 'admin@darulkitab.com'); // Update with your email

// Include database connection
require_once __DIR__ . '/db_connection.php';

/**
 * Check if user is logged in
 * 
 * @return bool True if user is logged in, false otherwise
 */
function isLoggedIn()
{
    return isset($_SESSION['user_id']) && !empty($_SESSION['user_id']);
}

/**
 * Redirect to a specified page
 * 
 * @param string $page The page to redirect to
 * @return void
 */
function redirect($page)
{
    header('Location: ' . BASE_URL . $page);
    exit;
}

/**
 * Display alert message
 * 
 * @param string $message The message to display
 * @param string $type The type of alert (success, danger, warning, info)
 * @return string HTML for the alert message
 */
function displayAlert($message, $type = 'info')
{
    return '<div class="alert alert-' . $type . ' alert-dismissible fade show" role="alert">
                ' . $message . '
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>';
}

/**
 * Set a flash message to be displayed on the next page
 * 
 * @param string $message The message to display
 * @param string $type The type of alert (success, danger, warning, info)
 * @return void
 */
function setFlashMessage($message, $type = 'info')
{
    $_SESSION['flash_message'] = [
        'message' => $message,
        'type' => $type
    ];
}

/**
 * Display flash message if it exists
 * 
 * @return string|null HTML for the flash message or null if none exists
 */
function displayFlashMessage()
{
    if (isset($_SESSION['flash_message'])) {
        $message = displayAlert($_SESSION['flash_message']['message'], $_SESSION['flash_message']['type']);
        unset($_SESSION['flash_message']);
        return $message;
    }
    return null;
}

/**
 * Format date for display
 * 
 * @param string $date The date to format
 * @param string $format The format to use (default: Y-m-d)
 * @return string The formatted date
 */
function formatDate($date, $format = 'Y-m-d')
{
    return date($format, strtotime($date));
}

/**
 * Format currency for display
 * 
 * @param float $amount The amount to format
 * @param string $currency The currency symbol (default: ₹)
 * @return string The formatted currency
 */
function formatCurrency($amount, $currency = '₹')
{
    return $currency . ' ' . number_format($amount, 2);
}

/**
 * Get user information by ID
 * 
 * @param int $userId The user ID
 * @return array|null The user information or null if not found
 */
function getUserById($userId)
{
    global $conn;

    $userId = (int)$userId;
    $sql = "SELECT id, username, full_name, email, role FROM users WHERE id = $userId";
    $result = executeQuery($conn, $sql);

    if ($result && $result->num_rows > 0) {
        return $result->fetch_assoc();
    }

    return null;
}

/**
 * Check if the current user has the required role
 * 
 * @param string|array $allowedRoles The role(s) allowed to access the page
 * @return bool True if user has the required role, false otherwise
 */
function hasRole($allowedRoles)
{
    if (!isLoggedIn()) {
        return false;
    }

    $userRole = $_SESSION['user_role'];

    if (is_array($allowedRoles)) {
        return in_array($userRole, $allowedRoles);
    } else {
        return $userRole === $allowedRoles;
    }
}

/**
 * Log system activity
 * 
 * @param string $action The action performed
 * @param string $description The description of the action
 * @param int $userId The ID of the user who performed the action
 * @return void
 */
function logActivity($action, $description, $userId = null)
{
    global $conn;

    $userId = $userId ?? ($_SESSION['user_id'] ?? 0);
    $action = sanitizeInput($conn, $action);
    $description = sanitizeInput($conn, $description);

    $sql = "INSERT INTO activity_log (user_id, action, description) 
            VALUES ($userId, '$action', '$description')";

    executeQuery($conn, $sql);
}

// Initialize the activity_log table if it doesn't exist
$createLogTable = "CREATE TABLE IF NOT EXISTS activity_log (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT NOT NULL,
    action VARCHAR(100) NOT NULL,
    description TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
)";

executeQuery($conn, $createLogTable);
