<?php

/**
 * Material Allocation Page
 * Handles allocating raw materials to production orders
 */
require_once '../includes/header.php';

// Get production orders
$ordersSql = "SELECT po.id, po.order_date, po.quantity, po.status, b.title 
               FROM production_orders po
               JOIN books b ON po.book_id = b.id
               WHERE po.status IN ('pending', 'printing')
               ORDER BY po.order_date DESC";
$ordersResult = executeQuery($conn, $ordersSql);

// Get available materials
$materialsSql = "SELECT id, material_type, batch_number, remaining_quantity, unit_price 
                 FROM raw_materials 
                 WHERE remaining_quantity > 0
                 ORDER BY material_type, purchase_date";
$materialsResult = executeQuery($conn, $materialsSql);

// Initialize arrays
$materials = [
    'paper' => [],
    'cover' => [],
    'half_title' => []
];

// Group materials by type
if ($materialsResult && $materialsResult->num_rows > 0) {
    while ($material = $materialsResult->fetch_assoc()) {
        $materials[$material['material_type']][] = $material;
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $productionOrderId = (int)$_POST['production_order_id'];
    $paperMaterialId = (int)$_POST['paper_material_id'];
    $coverMaterialId = (int)$_POST['cover_material_id'];
    $halfTitleMaterialId = (int)$_POST['half_title_material_id'];
    $paperQuantity = (int)$_POST['paper_quantity'];
    $coverQuantity = (int)$_POST['cover_quantity'];
    $halfTitleQuantity = (int)$_POST['half_title_quantity'];
    $allocationDate = sanitizeInput($conn, $_POST['allocation_date']);

    // Get production order details
    $orderSql = "SELECT * FROM production_orders WHERE id = $productionOrderId";
    $orderResult = executeQuery($conn, $orderSql);
    $order = $orderResult->fetch_assoc();

    // Validate input
    $errors = [];

    if ($paperMaterialId <= 0 || $coverMaterialId <= 0 || $halfTitleMaterialId <= 0) {
        $errors[] = 'All material types must be selected.';
    }

    if ($paperQuantity <= 0 || $coverQuantity <= 0 || $halfTitleQuantity <= 0) {
        $errors[] = 'All quantities must be greater than zero.';
    }

    // Check if we have enough materials
    // Paper
    $paperSql = "SELECT remaining_quantity FROM raw_materials WHERE id = $paperMaterialId";
    $paperResult = executeQuery($conn, $paperSql);
    $paper = $paperResult->fetch_assoc();

    if ($paperQuantity > $paper['remaining_quantity']) {
        $errors[] = 'Not enough paper available. Maximum available: ' . $paper['remaining_quantity'];
    }

    // Cover
    $coverSql = "SELECT remaining_quantity FROM raw_materials WHERE id = $coverMaterialId";
    $coverResult = executeQuery($conn, $coverSql);
    $cover = $coverResult->fetch_assoc();

    if ($coverQuantity > $cover['remaining_quantity']) {
        $errors[] = 'Not enough covers available. Maximum available: ' . $cover['remaining_quantity'];
    }

    // Half Title
    $titleSql = "SELECT remaining_quantity FROM raw_materials WHERE id = $halfTitleMaterialId";
    $titleResult = executeQuery($conn, $titleSql);
    $title = $titleResult->fetch_assoc();

    if ($halfTitleQuantity > $title['remaining_quantity']) {
        $errors[] = 'Not enough half titles available. Maximum available: ' . $title['remaining_quantity'];
    }

    // If no errors, allocate materials
    if (empty($errors)) {
        // Start transaction
        $conn->begin_transaction();

        try {
            // Insert allocations
            // Paper
            $paperSql = "INSERT INTO material_allocations (
                        production_order_id, 
                        raw_material_id, 
                        quantity_allocated, 
                        allocation_date
                    ) VALUES (
                        $productionOrderId, 
                        $paperMaterialId, 
                        $paperQuantity, 
                        '$allocationDate'
                    )";
            executeQuery($conn, $paperSql);

            // Cover
            $coverSql = "INSERT INTO material_allocations (
                        production_order_id, 
                        raw_material_id, 
                        quantity_allocated, 
                        allocation_date
                    ) VALUES (
                        $productionOrderId, 
                        $coverMaterialId, 
                        $coverQuantity, 
                        '$allocationDate'
                    )";
            executeQuery($conn, $coverSql);

            // Half Title
            $titleSql = "INSERT INTO material_allocations (
                        production_order_id, 
                        raw_material_id, 
                        quantity_allocated, 
                        allocation_date
                    ) VALUES (
                        $productionOrderId, 
                        $halfTitleMaterialId, 
                        $halfTitleQuantity, 
                        '$allocationDate'
                    )";
            executeQuery($conn, $titleSql);

            // Update remaining quantities
            // Paper
            $updatePaperSql = "UPDATE raw_materials 
                            SET remaining_quantity = remaining_quantity - $paperQuantity 
                            WHERE id = $paperMaterialId";
            executeQuery($conn, $updatePaperSql);

            // Cover
            $updateCoverSql = "UPDATE raw_materials 
                            SET remaining_quantity = remaining_quantity - $coverQuantity 
                            WHERE id = $coverMaterialId";
            executeQuery($conn, $updateCoverSql);

            // Half Title
            $updateTitleSql = "UPDATE raw_materials 
                            SET remaining_quantity = remaining_quantity - $halfTitleQuantity 
                            WHERE id = $halfTitleMaterialId";
            executeQuery($conn, $updateTitleSql);

            // Update production order status to 'printing' if it's pending
            if ($order['status'] === 'pending') {
                $updateOrderSql = "UPDATE production_orders 
                                SET status = 'printing' 
                                WHERE id = $productionOrderId";
                executeQuery($conn, $updateOrderSql);
            }

            // Commit transaction
            $conn->commit();

            logActivity('allocate_materials', "Allocated materials to production order ID: $productionOrderId");

            setFlashMessage('Materials allocated successfully.', 'success');
            redirect('production/orders.php');
        } catch (Exception $e) {
            // Rollback transaction on error
            $conn->rollback();
            $errors[] = 'Error allocating materials: ' . $e->getMessage();
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Allocate Materials to Production</h1>
    <div>
        <a href="../production/orders.php" class="btn btn-secondary me-2">
            <i class="fas fa-arrow-left"></i> Production Orders
        </a>
        <a href="list.php" class="btn btn-info">
            <i class="fas fa-box"></i> Materials Inventory
        </a>
    </div>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if (!$ordersResult || $ordersResult->num_rows === 0): ?>
    <div class="alert alert-info">
        <i class="fas fa-info-circle"></i> No production orders available for material allocation.
    </div>
<?php else: ?>
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Allocate Materials</h6>
        </div>
        <div class="card-body">
            <form method="post" action="">
                <div class="mb-4">
                    <label for="production_order_id" class="form-label">Select Production Order *</label>
                    <select name="production_order_id" id="production_order_id" class="form-select" required>
                        <option value="">Select Production Order</option>
                        <?php while ($order = $ordersResult->fetch_assoc()): ?>
                            <option value="<?php echo $order['id']; ?>">
                                ID: <?php echo $order['id']; ?> -
                                <?php echo htmlspecialchars($order['title']); ?> -
                                Quantity: <?php echo number_format($order['quantity']); ?> -
                                Date: <?php echo formatDate($order['order_date']); ?>
                            </option>
                        <?php endwhile; ?>
                    </select>
                </div>

                <div class="mb-3">
                    <label for="allocation_date" class="form-label">Allocation Date *</label>
                    <input type="date" class="form-control" id="allocation_date" name="allocation_date" value="<?php echo date('Y-m-d'); ?>" required>
                </div>

                <h5 class="mt-4 mb-3">Material Selection</h5>

                <!-- Paper Allocation -->
                <div class="card mb-3">
                    <div class="card-header bg-primary text-white">
                        Paper
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-8">
                                <label for="paper_material_id" class="form-label">Select Paper *</label>
                                <select name="paper_material_id" id="paper_material_id" class="form-select" required>
                                    <option value="">Select Paper</option>
                                    <?php foreach ($materials['paper'] as $paper): ?>
                                        <option value="<?php echo $paper['id']; ?>" data-available="<?php echo $paper['remaining_quantity']; ?>" data-price="<?php echo $paper['unit_price']; ?>">
                                            Batch: <?php echo htmlspecialchars($paper['batch_number']); ?> -
                                            Available: <?php echo number_format($paper['remaining_quantity']); ?> -
                                            Price: <?php echo formatCurrency($paper['unit_price']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="col-md-4">
                                <label for="paper_quantity" class="form-label">Quantity *</label>
                                <input type="number" class="form-control" id="paper_quantity" name="paper_quantity" min="1" required>
                                <small class="text-muted">Available: <span id="paper_available">0</span></small>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Cover Allocation -->
                <div class="card mb-3">
                    <div class="card-header bg-success text-white">
                        Cover
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-8">
                                <label for="cover_material_id" class="form-label">Select Cover *</label>
                                <select name="cover_material_id" id="cover_material_id" class="form-select" required>
                                    <option value="">Select Cover</option>
                                    <?php foreach ($materials['cover'] as $cover): ?>
                                        <option value="<?php echo $cover['id']; ?>" data-available="<?php echo $cover['remaining_quantity']; ?>" data-price="<?php echo $cover['unit_price']; ?>">
                                            Batch: <?php echo htmlspecialchars($cover['batch_number']); ?> -
                                            Available: <?php echo number_format($cover['remaining_quantity']); ?> -
                                            Price: <?php echo formatCurrency($cover['unit_price']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="col-md-4">
                                <label for="cover_quantity" class="form-label">Quantity *</label>
                                <input type="number" class="form-control" id="cover_quantity" name="cover_quantity" min="1" required>
                                <small class="text-muted">Available: <span id="cover_available">0</span></small>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Half Title Allocation -->
                <div class="card mb-3">
                    <div class="card-header bg-info text-white">
                        Half Title
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-8">
                                <label for="half_title_material_id" class="form-label">Select Half Title *</label>
                                <select name="half_title_material_id" id="half_title_material_id" class="form-select" required>
                                    <option value="">Select Half Title</option>
                                    <?php foreach ($materials['half_title'] as $halfTitle): ?>
                                        <option value="<?php echo $halfTitle['id']; ?>" data-available="<?php echo $halfTitle['remaining_quantity']; ?>" data-price="<?php echo $halfTitle['unit_price']; ?>">
                                            Batch: <?php echo htmlspecialchars($halfTitle['batch_number']); ?> -
                                            Available: <?php echo number_format($halfTitle['remaining_quantity']); ?> -
                                            Price: <?php echo formatCurrency($halfTitle['unit_price']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="col-md-4">
                                <label for="half_title_quantity" class="form-label">Quantity *</label>
                                <input type="number" class="form-control" id="half_title_quantity" name="half_title_quantity" min="1" required>
                                <small class="text-muted">Available: <span id="half_title_available">0</span></small>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-4">
                    <div class="card-header bg-warning">
                        <h6 class="m-0 font-weight-bold">Allocation Summary</h6>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-4">
                                <p><strong>Paper:</strong> <span id="paper_summary">Not selected</span></p>
                            </div>
                            <div class="col-md-4">
                                <p><strong>Cover:</strong> <span id="cover_summary">Not selected</span></p>
                            </div>
                            <div class="col-md-4">
                                <p><strong>Half Title:</strong> <span id="half_title_summary">Not selected</span></p>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <p class="mb-0"><strong>Total Estimated Cost:</strong> <span id="total_cost">₹ 0.00</span></p>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                    <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                    <button type="submit" class="btn btn-primary">Allocate Materials</button>
                </div>
            </form>
        </div>
    </div>
<?php endif; ?>

<script>
    // Update available quantity and summary when material is selected
    document.getElementById('paper_material_id').addEventListener('change', function() {
        const selectedOption = this.options[this.selectedIndex];
        const available = selectedOption.getAttribute('data-available');
        const price = selectedOption.getAttribute('data-price');

        document.getElementById('paper_available').textContent = available ? parseInt(available).toLocaleString() : '0';
        document.getElementById('paper_quantity').max = available;

        updateSummary();
    });

    document.getElementById('cover_material_id').addEventListener('change', function() {
        const selectedOption = this.options[this.selectedIndex];
        const available = selectedOption.getAttribute('data-available');
        const price = selectedOption.getAttribute('data-price');

        document.getElementById('cover_available').textContent = available ? parseInt(available).toLocaleString() : '0';
        document.getElementById('cover_quantity').max = available;

        updateSummary();
    });

    document.getElementById('half_title_material_id').addEventListener('change', function() {
        const selectedOption = this.options[this.selectedIndex];
        const available = selectedOption.getAttribute('data-available');
        const price = selectedOption.getAttribute('data-price');

        document.getElementById('half_title_available').textContent = available ? parseInt(available).toLocaleString() : '0';
        document.getElementById('half_title_quantity').max = available;

        updateSummary();
    });

    // Update quantities and summary
    document.getElementById('paper_quantity').addEventListener('input', updateSummary);
    document.getElementById('cover_quantity').addEventListener('input', updateSummary);
    document.getElementById('half_title_quantity').addEventListener('input', updateSummary);

    // Function to update summary
    function updateSummary() {
        // Paper
        const paperSelect = document.getElementById('paper_material_id');
        const paperSelectedOption = paperSelect.options[paperSelect.selectedIndex];
        const paperQuantity = parseInt(document.getElementById('paper_quantity').value) || 0;
        const paperPrice = parseFloat(paperSelectedOption?.getAttribute('data-price')) || 0;
        const paperCost = paperQuantity * paperPrice;

        // Cover
        const coverSelect = document.getElementById('cover_material_id');
        const coverSelectedOption = coverSelect.options[coverSelect.selectedIndex];
        const coverQuantity = parseInt(document.getElementById('cover_quantity').value) || 0;
        const coverPrice = parseFloat(coverSelectedOption?.getAttribute('data-price')) || 0;
        const coverCost = coverQuantity * coverPrice;

        // Half Title
        const titleSelect = document.getElementById('half_title_material_id');
        const titleSelectedOption = titleSelect.options[titleSelect.selectedIndex];
        const titleQuantity = parseInt(document.getElementById('half_title_quantity').value) || 0;
        const titlePrice = parseFloat(titleSelectedOption?.getAttribute('data-price')) || 0;
        const titleCost = titleQuantity * titlePrice;

        // Update summaries
        document.getElementById('paper_summary').textContent = paperSelectedOption && paperQuantity ?
            `${paperQuantity.toLocaleString()} units at ₹${paperPrice.toFixed(2)} each` : 'Not selected';

        document.getElementById('cover_summary').textContent = coverSelectedOption && coverQuantity ?
            `${coverQuantity.toLocaleString()} units at ₹${coverPrice.toFixed(2)} each` : 'Not selected';

        document.getElementById('half_title_summary').textContent = titleSelectedOption && titleQuantity ?
            `${titleQuantity.toLocaleString()} units at ₹${titlePrice.toFixed(2)} each` : 'Not selected';

        // Calculate total cost
        const totalCost = paperCost + coverCost + titleCost;
        document.getElementById('total_cost').textContent = `₹ ${totalCost.toFixed(2)}`;
    }

    // Initialize summary on page load
    updateSummary();
</script>

<?php require_once '../includes/footer.php'; ?>