<?php

/**
 * Edit Raw Material Page
 * Allows editing existing raw material records
 */
require_once '../includes/header.php';

// Check if ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    setFlashMessage('Material ID is required.', 'danger');
    redirect('materials/list.php');
}

$id = (int)$_GET['id'];

// Get material data
$sql = "SELECT * FROM raw_materials WHERE id = $id";
$result = executeQuery($conn, $sql);

if (!$result || $result->num_rows === 0) {
    setFlashMessage('Material not found.', 'danger');
    redirect('materials/list.php');
}

$material = $result->fetch_assoc();

// Check if material is allocated
$checkSql = "SELECT COUNT(*) AS count FROM material_allocations WHERE raw_material_id = $id";
$checkResult = executeQuery($conn, $checkSql);
$row = $checkResult->fetch_assoc();
$isAllocated = ($row['count'] > 0);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Sanitize input
    $materialType = sanitizeInput($conn, $_POST['material_type']);
    $quantity = (int)$_POST['quantity'];
    $unitPrice = (float)$_POST['unit_price'];
    $purchaseDate = sanitizeInput($conn, $_POST['purchase_date']);
    $batchNumber = sanitizeInput($conn, $_POST['batch_number']);
    $supplierName = sanitizeInput($conn, $_POST['supplier_name']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Calculate new remaining quantity if original quantity changes
    $remainingQuantity = $material['remaining_quantity'];
    if ($quantity != $material['quantity']) {
        // Calculate the difference between new and old quantity
        $quantityDiff = $quantity - $material['quantity'];
        // Add this difference to the remaining quantity
        $remainingQuantity = $material['remaining_quantity'] + $quantityDiff;

        // Ensure remaining quantity is not negative
        if ($remainingQuantity < 0) {
            $remainingQuantity = 0;
        }
    }

    // Validate input
    $errors = [];

    if (empty($materialType)) {
        $errors[] = 'Material type is required.';
    }

    if ($quantity <= 0) {
        $errors[] = 'Quantity must be greater than zero.';
    }

    if ($unitPrice <= 0) {
        $errors[] = 'Unit price must be greater than zero.';
    }

    if (empty($purchaseDate)) {
        $errors[] = 'Purchase date is required.';
    }

    if (empty($batchNumber)) {
        $errors[] = 'Batch number is required.';
    }

    // If material is allocated, check that there's enough quantity
    if ($isAllocated && $remainingQuantity < 0) {
        $errors[] = 'Cannot reduce quantity below the amount already allocated to production orders.';
    }

    // If no errors, update data
    if (empty($errors)) {
        $sql = "UPDATE raw_materials SET 
                material_type = '$materialType',
                quantity = $quantity,
                unit_price = $unitPrice,
                purchase_date = '$purchaseDate',
                batch_number = '$batchNumber',
                remaining_quantity = $remainingQuantity,
                supplier_name = '$supplierName',
                notes = '$notes'
                WHERE id = $id";

        if (executeQuery($conn, $sql)) {
            logActivity('edit_material', "Updated material ID: $id");

            setFlashMessage('Raw material updated successfully.', 'success');
            redirect('materials/list.php');
        } else {
            $errors[] = 'Error updating raw material. Please try again.';
        }
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1>Edit Raw Material</h1>
    <a href="list.php" class="btn btn-secondary">
        <i class="fas fa-arrow-left"></i> Back to List
    </a>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if ($isAllocated): ?>
    <div class="alert alert-warning">
        <i class="fas fa-exclamation-triangle"></i> This material has been allocated to production orders. Some fields may be restricted from editing.
    </div>
<?php endif; ?>

<div class="card shadow mb-4">
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Material Details</h6>
    </div>
    <div class="card-body">
        <form method="post" action="">
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="material_type" class="form-label">Material Type *</label>
                    <select name="material_type" id="material_type" class="form-select" required <?php echo $isAllocated ? 'disabled' : ''; ?>>
                        <option value="">Select Material Type</option>
                        <option value="paper" <?php echo ($material['material_type'] === 'paper') ? 'selected' : ''; ?>>Paper</option>
                        <option value="cover" <?php echo ($material['material_type'] === 'cover') ? 'selected' : ''; ?>>Cover</option>
                        <option value="half_title" <?php echo ($material['material_type'] === 'half_title') ? 'selected' : ''; ?>>Half Title</option>
                    </select>
                    <?php if ($isAllocated): ?>
                        <input type="hidden" name="material_type" value="<?php echo $material['material_type']; ?>">
                    <?php endif; ?>
                </div>
                <div class="col-md-6">
                    <label for="batch_number" class="form-label">Batch Number *</label>
                    <input type="text" class="form-control" id="batch_number" name="batch_number" value="<?php echo htmlspecialchars($material['batch_number']); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="quantity" class="form-label">Quantity *</label>
                    <input type="number" class="form-control" id="quantity" name="quantity" value="<?php echo htmlspecialchars($material['quantity']); ?>" min="1" required>
                    <small class="text-muted">Original quantity purchased</small>
                </div>
                <div class="col-md-6">
                    <label for="remaining_quantity" class="form-label">Remaining Quantity</label>
                    <input type="number" class="form-control" id="remaining_quantity" value="<?php echo htmlspecialchars($material['remaining_quantity']); ?>" disabled>
                    <small class="text-muted">This will be automatically calculated</small>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="unit_price" class="form-label">Unit Price *</label>
                    <div class="input-group">
                        <span class="input-group-text">₹</span>
                        <input type="number" class="form-control" id="unit_price" name="unit_price" value="<?php echo htmlspecialchars($material['unit_price']); ?>" min="0.01" step="0.01" required>
                    </div>
                </div>
                <div class="col-md-6">
                    <label for="purchase_date" class="form-label">Purchase Date *</label>
                    <input type="date" class="form-control" id="purchase_date" name="purchase_date" value="<?php echo htmlspecialchars($material['purchase_date']); ?>" required>
                </div>
            </div>

            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="supplier_name" class="form-label">Supplier Name</label>
                    <input type="text" class="form-control" id="supplier_name" name="supplier_name" value="<?php echo htmlspecialchars($material['supplier_name'] ?? ''); ?>">
                </div>
                <div class="col-md-6">
                    <label for="created_at" class="form-label">Record Created</label>
                    <input type="text" class="form-control" id="created_at" value="<?php echo formatDate($material['created_at'], 'Y-m-d H:i:s'); ?>" disabled>
                </div>
            </div>

            <div class="mb-3">
                <label for="notes" class="form-label">Notes</label>
                <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo htmlspecialchars($material['notes'] ?? ''); ?></textarea>
            </div>

            <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                <a href="list.php" class="btn btn-secondary me-md-2">Cancel</a>
                <button type="submit" class="btn btn-primary">Update Material</button>
            </div>
        </form>
    </div>
</div>

<?php require_once '../includes/footer.php'; ?>