<?php

/**
 * Production Orders Page
 * Manages production orders for books
 */
require_once '../includes/header.php';

// Check if this is a new order request
$isNewOrder = isset($_GET['action']) && $_GET['action'] === 'new';

// Handle form submission for new production order
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_order'])) {
    $bookId = (int)$_POST['book_id'];
    $quantity = (int)$_POST['quantity'];
    $orderDate = sanitizeInput($conn, $_POST['order_date']);
    $notes = sanitizeInput($conn, $_POST['notes']);

    // Validate input
    $errors = [];

    if ($bookId <= 0) {
        $errors[] = 'Please select a valid book.';
    }

    if ($quantity <= 0) {
        $errors[] = 'Quantity must be greater than zero.';
    }

    if (empty($orderDate)) {
        $errors[] = 'Order date is required.';
    }

    // If no errors, create the production order
    if (empty($errors)) {
        $sql = "INSERT INTO production_orders (
                    book_id, 
                    order_date, 
                    quantity, 
                    status, 
                    notes
                ) VALUES (
                    $bookId, 
                    '$orderDate', 
                    $quantity, 
                    'pending', 
                    '$notes'
                )";

        if (executeQuery($conn, $sql)) {
            $orderId = $conn->insert_id;

            // Get book title for log
            $bookSql = "SELECT title FROM books WHERE id = $bookId";
            $bookResult = executeQuery($conn, $bookSql);
            $book = $bookResult->fetch_assoc();

            logActivity('create_production_order', "Created production order #$orderId for {$book['title']}, quantity: $quantity");

            setFlashMessage('Production order created successfully.', 'success');
            redirect('production/orders.php');
        } else {
            $errors[] = 'Error creating production order. Please try again.';
        }
    }
}

// Handle order cancellation
if (isset($_GET['cancel']) && !empty($_GET['cancel'])) {
    $orderId = (int)$_GET['cancel'];

    // Check if order can be cancelled (must be in pending or printing status)
    $checkSql = "SELECT status FROM production_orders WHERE id = $orderId";
    $checkResult = executeQuery($conn, $checkSql);
    $order = $checkResult->fetch_assoc();

    if ($order && ($order['status'] === 'pending' || $order['status'] === 'printing')) {
        // Check if materials have been allocated
        $allocCheckSql = "SELECT COUNT(*) AS count FROM material_allocations WHERE production_order_id = $orderId";
        $allocCheckResult = executeQuery($conn, $allocCheckSql);
        $allocCount = $allocCheckResult->fetch_assoc();

        if ($allocCount['count'] > 0) {
            // Materials allocated - need to return them to inventory
            $allocSql = "SELECT raw_material_id, quantity_allocated FROM material_allocations WHERE production_order_id = $orderId";
            $allocResult = executeQuery($conn, $allocSql);

            // Start transaction
            $conn->begin_transaction();

            try {
                // Return each allocated material back to inventory
                while ($alloc = $allocResult->fetch_assoc()) {
                    $materialId = $alloc['raw_material_id'];
                    $quantity = $alloc['quantity_allocated'];

                    $updateSql = "UPDATE raw_materials 
                                 SET remaining_quantity = remaining_quantity + $quantity 
                                 WHERE id = $materialId";
                    executeQuery($conn, $updateSql);
                }

                // Delete allocations
                $deleteAllocSql = "DELETE FROM material_allocations WHERE production_order_id = $orderId";
                executeQuery($conn, $deleteAllocSql);

                // Update order status to cancelled
                $updateOrderSql = "UPDATE production_orders SET status = 'cancelled' WHERE id = $orderId";
                executeQuery($conn, $updateOrderSql);

                // Commit transaction
                $conn->commit();

                logActivity('cancel_production_order', "Cancelled production order #$orderId and returned materials to inventory");
                setFlashMessage('Production order cancelled and materials returned to inventory.', 'success');
            } catch (Exception $e) {
                // Rollback on error
                $conn->rollback();
                setFlashMessage('Error cancelling production order: ' . $e->getMessage(), 'danger');
            }
        } else {
            // No materials allocated - simple cancellation
            $updateOrderSql = "UPDATE production_orders SET status = 'cancelled' WHERE id = $orderId";
            if (executeQuery($conn, $updateOrderSql)) {
                logActivity('cancel_production_order', "Cancelled production order #$orderId");
                setFlashMessage('Production order cancelled successfully.', 'success');
            } else {
                setFlashMessage('Error cancelling production order.', 'danger');
            }
        }
    } else {
        setFlashMessage('Cannot cancel this production order due to its current status.', 'danger');
    }

    redirect('production/orders.php');
}

// Get active books for the dropdown
$booksSql = "SELECT id, title FROM books WHERE active = 1 ORDER BY title";
$booksResult = executeQuery($conn, $booksSql);

// Get filter parameters
$status = isset($_GET['status']) ? sanitizeInput($conn, $_GET['status']) : '';
$dateFrom = isset($_GET['date_from']) ? sanitizeInput($conn, $_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitizeInput($conn, $_GET['date_to']) : '';
$bookFilter = isset($_GET['book_id']) ? (int)$_GET['book_id'] : 0;

// Build query with filters
$sql = "SELECT po.*, b.title AS book_title 
        FROM production_orders po
        JOIN books b ON po.book_id = b.id
        WHERE 1=1";

if (!empty($status)) {
    $sql .= " AND po.status = '$status'";
}

if (!empty($dateFrom)) {
    $sql .= " AND po.order_date >= '$dateFrom'";
}

if (!empty($dateTo)) {
    $sql .= " AND po.order_date <= '$dateTo'";
}

if ($bookFilter > 0) {
    $sql .= " AND po.book_id = $bookFilter";
}

$sql .= " ORDER BY po.order_date DESC";

$result = executeQuery($conn, $sql);

// Get material allocation status for each order
$orderAllocations = [];
$allocSql = "SELECT production_order_id, COUNT(*) AS allocation_count 
            FROM material_allocations 
            GROUP BY production_order_id";
$allocResult = executeQuery($conn, $allocSql);

if ($allocResult && $allocResult->num_rows > 0) {
    while ($alloc = $allocResult->fetch_assoc()) {
        $orderAllocations[$alloc['production_order_id']] = $alloc['allocation_count'];
    }
}

// Get printing jobs status for each order
$orderPrinting = [];
$printingSql = "SELECT production_order_id, SUM(received_quantity) AS total_printed 
               FROM printing_jobs 
               GROUP BY production_order_id";
$printingResult = executeQuery($conn, $printingSql);

if ($printingResult && $printingResult->num_rows > 0) {
    while ($printing = $printingResult->fetch_assoc()) {
        $orderPrinting[$printing['production_order_id']] = $printing['total_printed'];
    }
}

// Get binding jobs status for each order
$orderBinding = [];
$bindingSql = "SELECT production_order_id, SUM(received_quantity) AS total_bound 
              FROM binding_jobs 
              GROUP BY production_order_id";
$bindingResult = executeQuery($conn, $bindingSql);

if ($bindingResult && $bindingResult->num_rows > 0) {
    while ($binding = $bindingResult->fetch_assoc()) {
        $orderBinding[$binding['production_order_id']] = $binding['total_bound'];
    }
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h1><?php echo $isNewOrder ? 'Create New Production Order' : 'Production Orders'; ?></h1>
    <?php if (!$isNewOrder): ?>
        <a href="orders.php?action=new" class="btn btn-primary">
            <i class="fas fa-plus"></i> New Production Order
        </a>
    <?php else: ?>
        <a href="orders.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Back to Orders
        </a>
    <?php endif; ?>
</div>

<?php if (!empty($errors)): ?>
    <div class="alert alert-danger">
        <ul class="mb-0">
            <?php foreach ($errors as $error): ?>
                <li><?php echo $error; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
<?php endif; ?>

<?php if ($isNewOrder): ?>
    <!-- New Production Order Form -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Create New Production Order</h6>
        </div>
        <div class="card-body">
            <form method="post" action="">
                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="book_id" class="form-label">Book *</label>
                        <select name="book_id" id="book_id" class="form-select" required>
                            <option value="">Select Book</option>
                            <?php if ($booksResult && $booksResult->num_rows > 0): ?>
                                <?php while ($book = $booksResult->fetch_assoc()): ?>
                                    <option value="<?php echo $book['id']; ?>">
                                        <?php echo htmlspecialchars($book['title']); ?>
                                    </option>
                                <?php endwhile; ?>
                            <?php endif; ?>
                        </select>
                    </div>
                    <div class="col-md-6">
                        <label for="quantity" class="form-label">Quantity *</label>
                        <input type="number" class="form-control" id="quantity" name="quantity" min="1" required>
                    </div>
                </div>

                <div class="row mb-3">
                    <div class="col-md-6">
                        <label for="order_date" class="form-label">Order Date *</label>
                        <input type="date" class="form-control" id="order_date" name="order_date" value="<?php echo date('Y-m-d'); ?>" required>
                    </div>
                    <div class="col-md-6">
                        <label for="status" class="form-label">Status</label>
                        <input type="text" class="form-control" id="status" value="Pending" disabled>
                        <small class="text-muted">New orders are automatically set to Pending status</small>
                    </div>
                </div>

                <div class="mb-3">
                    <label for="notes" class="form-label">Notes</label>
                    <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                </div>

                <div class="alert alert-info">
                    <i class="fas fa-info-circle"></i> After creating a production order, you'll need to:
                    <ol class="mb-0">
                        <li>Allocate raw materials from the Materials menu</li>
                        <li>Create printing jobs for printing process</li>
                        <li>Create binding jobs for binding process</li>
                    </ol>
                </div>

                <div class="d-grid gap-2 d-md-flex justify-content-md-end">
                    <button type="reset" class="btn btn-secondary me-md-2">Reset</button>
                    <button type="submit" name="create_order" class="btn btn-primary">Create Order</button>
                </div>
            </form>
        </div>
    </div>

<?php else: ?>

    <!-- Filters -->
    <div class="card mb-4">
        <div class="card-header">
            <i class="fas fa-filter"></i> Filter Orders
        </div>
        <div class="card-body">
            <form method="get" action="" class="row g-3">
                <div class="col-md-3">
                    <label for="status" class="form-label">Status</label>
                    <select name="status" id="status" class="form-select">
                        <option value="">All Statuses</option>
                        <option value="pending" <?php echo ($status === 'pending') ? 'selected' : ''; ?>>Pending</option>
                        <option value="printing" <?php echo ($status === 'printing') ? 'selected' : ''; ?>>Printing</option>
                        <option value="binding" <?php echo ($status === 'binding') ? 'selected' : ''; ?>>Binding</option>
                        <option value="completed" <?php echo ($status === 'completed') ? 'selected' : ''; ?>>Completed</option>
                        <option value="cancelled" <?php echo ($status === 'cancelled') ? 'selected' : ''; ?>>Cancelled</option>
                    </select>
                </div>
                <div class="col-md-3">
                    <label for="book_id" class="form-label">Book</label>
                    <select name="book_id" id="book_id" class="form-select">
                        <option value="">All Books</option>
                        <?php
                        // Reset pointer to the beginning
                        if ($booksResult) {
                            $booksResult->data_seek(0);
                            while ($book = $booksResult->fetch_assoc()):
                        ?>
                                <option value="<?php echo $book['id']; ?>" <?php echo ($bookFilter == $book['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($book['title']); ?>
                                </option>
                        <?php
                            endwhile;
                        }
                        ?>
                    </select>
                </div>
                <div class="col-md-2">
                    <label for="date_from" class="form-label">Date From</label>
                    <input type="date" class="form-control" id="date_from" name="date_from" value="<?php echo htmlspecialchars($dateFrom); ?>">
                </div>
                <div class="col-md-2">
                    <label for="date_to" class="form-label">Date To</label>
                    <input type="date" class="form-control" id="date_to" name="date_to" value="<?php echo htmlspecialchars($dateTo); ?>">
                </div>
                <div class="col-md-2 d-flex align-items-end">
                    <div class="d-grid gap-2 w-100">
                        <button type="submit" class="btn btn-primary">Filter</button>
                        <a href="orders.php" class="btn btn-secondary">Reset</a>
                    </div>
                </div>
            </form>
        </div>
    </div>

    <!-- Production Orders Table -->
    <div class="card shadow mb-4">
        <div class="card-header py-3">
            <h6 class="m-0 font-weight-bold text-primary">Production Orders</h6>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered" width="100%" cellspacing="0">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Book</th>
                            <th>Date</th>
                            <th>Quantity</th>
                            <th>Status</th>
                            <th>Materials</th>
                            <th>Printing</th>
                            <th>Binding</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if ($result && $result->num_rows > 0): ?>
                            <?php while ($row = $result->fetch_assoc()): ?>
                                <tr>
                                    <td><?php echo $row['id']; ?></td>
                                    <td><?php echo htmlspecialchars($row['book_title']); ?></td>
                                    <td><?php echo formatDate($row['order_date']); ?></td>
                                    <td><?php echo number_format($row['quantity']); ?></td>
                                    <td>
                                        <span class="badge bg-<?php
                                                                echo ($row['status'] === 'completed') ? 'success' : (($row['status'] === 'pending') ? 'warning' : (($row['status'] === 'cancelled') ? 'danger' : 'info'));
                                                                ?>">
                                            <?php echo ucfirst($row['status']); ?>
                                        </span>
                                    </td>
                                    <td>
                                        <?php if (isset($orderAllocations[$row['id']])): ?>
                                            <span class="badge bg-success">Allocated</span>
                                        <?php else: ?>
                                            <span class="badge bg-danger">Not Allocated</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php
                                        $printedQty = $orderPrinting[$row['id']] ?? 0;
                                        $printPercentage = ($row['quantity'] > 0) ? ($printedQty / $row['quantity'] * 100) : 0;
                                        ?>
                                        <div class="progress">
                                            <div class="progress-bar" role="progressbar" style="width: <?php echo $printPercentage; ?>%;"
                                                aria-valuenow="<?php echo $printPercentage; ?>" aria-valuemin="0" aria-valuemax="100">
                                                <?php echo number_format($printPercentage); ?>%
                                            </div>
                                        </div>
                                        <small><?php echo number_format($printedQty); ?> / <?php echo number_format($row['quantity']); ?></small>
                                    </td>
                                    <td>
                                        <?php
                                        $boundQty = $orderBinding[$row['id']] ?? 0;
                                        $bindPercentage = ($row['quantity'] > 0) ? ($boundQty / $row['quantity'] * 100) : 0;
                                        ?>
                                        <div class="progress">
                                            <div class="progress-bar bg-success" role="progressbar" style="width: <?php echo $bindPercentage; ?>%;"
                                                aria-valuenow="<?php echo $bindPercentage; ?>" aria-valuemin="0" aria-valuemax="100">
                                                <?php echo number_format($bindPercentage); ?>%
                                            </div>
                                        </div>
                                        <small><?php echo number_format($boundQty); ?> / <?php echo number_format($row['quantity']); ?></small>
                                    </td>
                                    <td>
                                        <div class="btn-group" role="group">
                                            <a href="view_order.php?id=<?php echo $row['id']; ?>" class="btn btn-info btn-sm">
                                                <i class="fas fa-eye"></i>
                                            </a>

                                            <?php if ($row['status'] !== 'cancelled' && $row['status'] !== 'completed'): ?>
                                                <?php if (!isset($orderAllocations[$row['id']])): ?>
                                                    <a href="../materials/allocate.php?order_id=<?php echo $row['id']; ?>" class="btn btn-primary btn-sm">
                                                        <i class="fas fa-boxes"></i> Allocate
                                                    </a>
                                                <?php endif; ?>

                                                <a href="printing.php?order_id=<?php echo $row['id']; ?>" class="btn btn-warning btn-sm">
                                                    <i class="fas fa-print"></i> Printing
                                                </a>

                                                <a href="binding.php?order_id=<?php echo $row['id']; ?>" class="btn btn-success btn-sm">
                                                    <i class="fas fa-book-open"></i> Binding
                                                </a>

                                                <?php if ($row['status'] !== 'completed'): ?>
                                                    <a href="orders.php?cancel=<?php echo $row['id']; ?>" class="btn btn-danger btn-sm"
                                                        onclick="return confirm('Are you sure you want to cancel this order? This will return any allocated materials to inventory.');">
                                                        <i class="fas fa-times"></i> Cancel
                                                    </a>
                                                <?php endif; ?>
                                            <?php endif; ?>
                                        </div>
                                    </td>
                                </tr>
                            <?php endwhile; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="9" class="text-center">No production orders found</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

<?php endif; ?>

<?php require_once '../includes/footer.php'; ?>